/*
 * Code for class DS_LINKABLE [INTEGER_32]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ds7079.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {DS_LINKABLE}.put_right */
void F1016_15469 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("put_right", 1015, Current, 0, 1, 13941);
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(3);
	RTEE;
}

/* {DS_LINKABLE}.forget_right */
void F1016_15470 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("forget_right", 1015, Current, 0, 0, 13942);
	RTHOOK(1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) NULL;
	RTHOOK(3);
	RTEE;
}

void EIF_Minit7079 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
